@@ -36,17 +36,13 @@ import static com.google.auth.oauth2.GoogleCredentials.SERVICE_ACCOUNT_FILE_TYPE
 import com.google.api.client.json.GenericJson;
 import com.google.api.client.json.JsonFactory;
 import com.google.api.client.json.JsonObjectParser;
-import com.google.api.client.json.webtoken.JsonWebSignature;
-import com.google.api.client.json.webtoken.JsonWebToken;
 import com.google.api.client.util.Clock;
 import com.google.api.client.util.Preconditions;
 import com.google.auth.Credentials;
 import com.google.auth.RequestMetadataCallback;
 import com.google.auth.ServiceAccountSigner;
-import com.google.auth.http.AuthHttpConstants;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.MoreObjects;
-
 import com.google.common.base.Throwables;
 import com.google.common.base.Ticker;
 import com.google.common.cache.CacheBuilder;
@@ -57,13 +53,11 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.net.URI;
-import java.security.GeneralSecurityException;
 import java.security.InvalidKeyException;
 import java.security.NoSuchAlgorithmException;
 import java.security.PrivateKey;
 import java.security.Signature;
 import java.security.SignatureException;
-import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
@@ -77,24 +71,24 @@ import java.util.concurrent.TimeUnit;
  * <p>Uses a JSON Web Token (JWT) directly in the request metadata to provide authorization.
  */
 public class ServiceAccountJwtAccessCredentials extends Credentials
-    implements ServiceAccountSigner {
+    implements JwtProvider, ServiceAccountSigner {
 
   private static final long serialVersionUID = -7274955171379494197L;
   static final String JWT_ACCESS_PREFIX = OAuth2Utils.BEARER_PREFIX;
-  @VisibleForTesting
-  static final long LIFE_SPAN_SECS = TimeUnit.HOURS.toSeconds(1);
+
+  @VisibleForTesting static final long LIFE_SPAN_SECS = TimeUnit.HOURS.toSeconds(1);
+  private static final long CLOCK_SKEW = TimeUnit.MINUTES.toSeconds(5);
 
   private final String clientId;
   private final String clientEmail;
   private final PrivateKey privateKey;
   private final String privateKeyId;
   private final URI defaultAudience;
-  private transient LoadingCache<URI, String> tokenCache;
 
+  private transient LoadingCache<JwtClaims, JwtCredentials> credentialsCache;
 
   // Until we expose this to the users it can remain transient and non-serializable
-  @VisibleForTesting
-  transient Clock clock = Clock.SYSTEM;
+  @VisibleForTesting transient Clock clock = Clock.SYSTEM;
 
   /**
    * Constructor with minimum identifying information.
@@ -104,7 +98,7 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param privateKey RSA private key object for the service account.
    * @param privateKeyId Private key identifier for the service account. May be null.
    * @deprecated Use {@link #newBuilder()} instead. This constructor will either be deleted or made
-   *             private in a later version.
+   *     private in a later version.
    */
   @Deprecated
   public ServiceAccountJwtAccessCredentials(
@@ -121,14 +115,18 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param privateKeyId Private key identifier for the service account. May be null.
    * @param defaultAudience Audience to use if not provided by transport. May be null.
    */
-  private ServiceAccountJwtAccessCredentials(String clientId, String clientEmail,
-      PrivateKey privateKey, String privateKeyId, URI defaultAudience) {
+  private ServiceAccountJwtAccessCredentials(
+      String clientId,
+      String clientEmail,
+      PrivateKey privateKey,
+      String privateKeyId,
+      URI defaultAudience) {
     this.clientId = clientId;
     this.clientEmail = Preconditions.checkNotNull(clientEmail);
     this.privateKey = Preconditions.checkNotNull(privateKey);
     this.privateKeyId = privateKeyId;
     this.defaultAudience = defaultAudience;
-    this.tokenCache = createCache();
+    this.credentialsCache = createCache();
   }
 
   /**
@@ -138,7 +136,7 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param json a map from the JSON representing the credentials.
    * @return the credentials defined by the JSON.
    * @throws IOException if the credential cannot be created from the JSON.
-   **/
+   */
   static ServiceAccountJwtAccessCredentials fromJson(Map<String, Object> json) throws IOException {
     return fromJson(json, null);
   }
@@ -151,17 +149,20 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param defaultAudience Audience to use if not provided by transport. May be null.
    * @return the credentials defined by the JSON.
    * @throws IOException if the credential cannot be created from the JSON.
-   **/
+   */
   static ServiceAccountJwtAccessCredentials fromJson(Map<String, Object> json, URI defaultAudience)
       throws IOException {
     String clientId = (String) json.get("client_id");
     String clientEmail = (String) json.get("client_email");
     String privateKeyPkcs8 = (String) json.get("private_key");
     String privateKeyId = (String) json.get("private_key_id");
-    if (clientId == null || clientEmail == null
-        || privateKeyPkcs8 == null || privateKeyId == null) {
-      throw new IOException("Error reading service account credential from JSON, "
-          + "expecting  'client_id', 'client_email', 'private_key' and 'private_key_id'.");
+    if (clientId == null
+        || clientEmail == null
+        || privateKeyPkcs8 == null
+        || privateKeyId == null) {
+      throw new IOException(
+          "Error reading service account credential from JSON, "
+              + "expecting  'client_id', 'client_email', 'private_key' and 'private_key_id'.");
     }
     return fromPkcs8(clientId, clientEmail, privateKeyPkcs8, privateKeyId, defaultAudience);
   }
@@ -176,8 +177,9 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @return New ServiceAccountJwtAcceessCredentials created from a private key.
    * @throws IOException if the credential cannot be created from the private key.
    */
-  public static ServiceAccountJwtAccessCredentials fromPkcs8(String clientId, String clientEmail, 
-      String privateKeyPkcs8, String privateKeyId) throws IOException {
+  public static ServiceAccountJwtAccessCredentials fromPkcs8(
+      String clientId, String clientEmail, String privateKeyPkcs8, String privateKeyId)
+      throws IOException {
     return fromPkcs8(clientId, clientEmail, privateKeyPkcs8, privateKeyId, null);
   }
 
@@ -192,8 +194,13 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @return New ServiceAccountJwtAcceessCredentials created from a private key.
    * @throws IOException if the credential cannot be created from the private key.
    */
-  public static ServiceAccountJwtAccessCredentials fromPkcs8(String clientId, String clientEmail, 
-      String privateKeyPkcs8, String privateKeyId, URI defaultAudience) throws IOException {
+  public static ServiceAccountJwtAccessCredentials fromPkcs8(
+      String clientId,
+      String clientEmail,
+      String privateKeyPkcs8,
+      String privateKeyId,
+      URI defaultAudience)
+      throws IOException {
     PrivateKey privateKey = ServiceAccountCredentials.privateKeyFromPkcs8(privateKeyPkcs8);
     return new ServiceAccountJwtAccessCredentials(
         clientId, clientEmail, privateKey, privateKeyId, defaultAudience);
@@ -206,7 +213,7 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param credentialsStream the stream with the credential definition.
    * @return the credential defined by the credentialsStream.
    * @throws IOException if the credential cannot be created from the stream.
-   **/
+   */
   public static ServiceAccountJwtAccessCredentials fromStream(InputStream credentialsStream)
       throws IOException {
     return fromStream(credentialsStream, null);
@@ -220,15 +227,15 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
    * @param defaultAudience Audience to use if not provided by transport. May be null.
    * @return the credential defined by the credentialsStream.
    * @throws IOException if the credential cannot be created from the stream.
-   **/
-  public static ServiceAccountJwtAccessCredentials fromStream(InputStream credentialsStream,
-      URI defaultAudience) throws IOException {
+   */
+  public static ServiceAccountJwtAccessCredentials fromStream(
+      InputStream credentialsStream, URI defaultAudience) throws IOException {
     Preconditions.checkNotNull(credentialsStream);
 
     JsonFactory jsonFactory = OAuth2Utils.JSON_FACTORY;
     JsonObjectParser parser = new JsonObjectParser(jsonFactory);
-    GenericJson fileContents = parser.parseAndClose(
-        credentialsStream, OAuth2Utils.UTF_8, GenericJson.class);
+    GenericJson fileContents =
+        parser.parseAndClose(credentialsStream, OAuth2Utils.UTF_8, GenericJson.class);
 
     String fileType = (String) fileContents.get("type");
     if (fileType == null) {
@@ -237,31 +244,60 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
     if (SERVICE_ACCOUNT_FILE_TYPE.equals(fileType)) {
       return fromJson(fileContents, defaultAudience);
     }
-    throw new IOException(String.format(
-        "Error reading credentials from stream, 'type' value '%s' not recognized."
-            + " Expecting '%s'.", fileType, SERVICE_ACCOUNT_FILE_TYPE));
+    throw new IOException(
+        String.format(
+            "Error reading credentials from stream, 'type' value '%s' not recognized."
+                + " Expecting '%s'.",
+            fileType, SERVICE_ACCOUNT_FILE_TYPE));
   }
 
-  private LoadingCache<URI, String> createCache() {
+  private LoadingCache<JwtClaims, JwtCredentials> createCache() {
     return CacheBuilder.newBuilder()
         .maximumSize(100)
-        .expireAfterWrite(LIFE_SPAN_SECS - 300, TimeUnit.SECONDS)
+        .expireAfterWrite(LIFE_SPAN_SECS - CLOCK_SKEW, TimeUnit.SECONDS)
         .ticker(
             new Ticker() {
               @Override
               public long read() {
                 return TimeUnit.MILLISECONDS.toNanos(clock.currentTimeMillis());
               }
-            }
-        )
+            })
         .build(
-            new CacheLoader<URI, String>() {
+            new CacheLoader<JwtClaims, JwtCredentials>() {
               @Override
-              public String load(URI key) throws Exception {
-                return generateJwtAccess(key);
+              public JwtCredentials load(JwtClaims claims) throws Exception {
+                return JwtCredentials.newBuilder()
+                    .setPrivateKey(privateKey)
+                    .setPrivateKeyId(privateKeyId)
+                    .setJwtClaims(claims)
+                    .setLifeSpanSeconds(LIFE_SPAN_SECS)
+                    .setClock(clock)
+                    .build();
               }
-            }
-        );
+            });
+  }
+
+  /**
+   * Returns a new JwtCredentials instance with modified claims.
+   *
+   * @param newClaims new claims. Any unspecified claim fields will default to the the current
+   *     values.
+   * @return new credentials
+   */
+  @Override
+  public JwtCredentials jwtWithClaims(JwtClaims newClaims) {
+    JwtClaims.Builder claimsBuilder =
+        JwtClaims.newBuilder().setIssuer(clientEmail).setSubject(clientEmail);
+    if (defaultAudience != null) {
+      claimsBuilder.setAudience(defaultAudience.toString());
+    }
+    return JwtCredentials.newBuilder()
+        .setPrivateKey(privateKey)
+        .setPrivateKeyId(privateKeyId)
+        .setJwtClaims(claimsBuilder.build().merge(newClaims))
+        .setLifeSpanSeconds(LIFE_SPAN_SECS)
+        .setClock(clock)
+        .build();
   }
 
   @Override
@@ -280,80 +316,53 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
   }
 
   @Override
-  public void getRequestMetadata(final URI uri, Executor executor,
-      final RequestMetadataCallback callback) {
+  public void getRequestMetadata(
+      final URI uri, Executor executor, final RequestMetadataCallback callback) {
     // It doesn't use network. Only some CPU work on par with TLS handshake. So it's preferrable
     // to do it in the current thread, which is likely to be the network thread.
     blockingGetToCallback(uri, callback);
   }
 
-  /**
-   * Provide the request metadata by putting an access JWT directly in the metadata.
-   */
+  /** Provide the request metadata by putting an access JWT directly in the metadata. */
   @Override
   public Map<String, List<String>> getRequestMetadata(URI uri) throws IOException {
     if (uri == null) {
       if (defaultAudience != null) {
         uri = defaultAudience;
       } else {
-        throw new IOException("JwtAccess requires Audience uri to be passed in or the " 
-          + "defaultAudience to be specified");
+        throw new IOException(
+            "JwtAccess requires Audience uri to be passed in or the "
+                + "defaultAudience to be specified");
       }
     }
-    String assertion = getJwtAccess(uri);
-    String authorizationHeader = JWT_ACCESS_PREFIX + assertion;
-    List<String> newAuthorizationHeaders = Collections.singletonList(authorizationHeader);
-    return Collections.singletonMap(AuthHttpConstants.AUTHORIZATION, newAuthorizationHeaders);
-  }
 
-  /**
-   * Discard any cached data
-   */
-  @Override
-  public void refresh() {
-    tokenCache.invalidateAll();
-  }
-
-  private String getJwtAccess(URI uri) throws IOException {
     try {
-      return tokenCache.get(uri);
+      JwtClaims defaultClaims =
+          JwtClaims.newBuilder()
+              .setAudience(uri.toString())
+              .setIssuer(clientEmail)
+              .setSubject(clientEmail)
+              .build();
+      JwtCredentials credentials = credentialsCache.get(defaultClaims);
+      return credentials.getRequestMetadata(uri);
     } catch (ExecutionException e) {
       Throwables.propagateIfPossible(e.getCause(), IOException.class);
       // Should never happen
-      throw new IllegalStateException("generateJwtAccess threw an unexpected checked exception", e.getCause());
+      throw new IllegalStateException(
+          "generateJwtAccess threw an unexpected checked exception", e.getCause());
 
     } catch (UncheckedExecutionException e) {
-      Throwables.propagateIfPossible(e);
+      Throwables.throwIfUnchecked(e);
       // Should never happen
-      throw new IllegalStateException("generateJwtAccess threw an unchecked exception that couldn't be rethrown", e);
+      throw new IllegalStateException(
+          "generateJwtAccess threw an unchecked exception that couldn't be rethrown", e);
     }
   }
 
-  private String generateJwtAccess(URI uri) throws IOException {
-    JsonWebSignature.Header header = new JsonWebSignature.Header();
-    header.setAlgorithm("RS256");
-    header.setType("JWT");
-    header.setKeyId(privateKeyId);
-
-    JsonWebToken.Payload payload = new JsonWebToken.Payload();
-    long currentTime = clock.currentTimeMillis();
-    // Both copies of the email are required
-    payload.setIssuer(clientEmail);
-    payload.setSubject(clientEmail);
-    payload.setAudience(uri.toString());
-    payload.setIssuedAtTimeSeconds(currentTime / 1000);
-    payload.setExpirationTimeSeconds(currentTime / 1000 + LIFE_SPAN_SECS);
-
-    JsonFactory jsonFactory = OAuth2Utils.JSON_FACTORY;
-
-    String assertion;
-    try {
-      assertion = JsonWebSignature.signUsingRsaSha256(
-          privateKey, jsonFactory, header, payload);
-    } catch (GeneralSecurityException e) {
-      throw new IOException("Error signing service account JWT access header with private key.", e);
-    }
-    return assertion;
+  /** Discard any cached data */
+  @Override
+  public void refresh() {
+    credentialsCache.invalidateAll();
   }
 
   public final String getClientId() {
@@ -420,7 +429,7 @@ public class ServiceAccountJwtAccessCredentials extends Credentials
   private void readObject(ObjectInputStream input) throws IOException, ClassNotFoundException {
     input.defaultReadObject();
     clock = Clock.SYSTEM;
-    tokenCache = createCache();
+    credentialsCache = createCache();
   }
 
   public static Builder newBuilder() {
