@@ -41,11 +41,6 @@ import com.google.api.client.testing.http.MockHttpTransport;
 import com.google.auth.TestUtils;
 import com.google.auth.http.HttpTransportFactory;
 import com.google.common.collect.ImmutableList;
-
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
-
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -56,10 +51,11 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicReference;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
-/**
- * Test case for {@link GoogleCredentials}.
- */
+/** Test case for {@link GoogleCredentials}. */
 @RunWith(JUnit4.class)
 public class GoogleCredentialsTest {
 
@@ -67,10 +63,9 @@ public class GoogleCredentialsTest {
       "36680232662-vrd7ji19qe3nelgchd0ah2csanun6bnr@developer.gserviceaccount.com";
   private static final String SA_CLIENT_ID =
       "36680232662-vrd7ji19qe3nelgchd0ah2csanun6bnr.apps.googleusercontent.com";
-  private static final String SA_PRIVATE_KEY_ID =
-      "d84a4fefcf50791d4a90f2d7af17469d6282df9d";
-  private static final String SA_PRIVATE_KEY_PKCS8
-      = ServiceAccountCredentialsTest.SA_PRIVATE_KEY_PKCS8;
+  private static final String SA_PRIVATE_KEY_ID = "d84a4fefcf50791d4a90f2d7af17469d6282df9d";
+  private static final String SA_PRIVATE_KEY_PKCS8 =
+      ServiceAccountCredentialsTest.SA_PRIVATE_KEY_PKCS8;
   private static final String USER_CLIENT_SECRET = "jakuaL9YyieakhECKL2SwZcu";
   private static final String USER_CLIENT_ID = "ya29.1.AADtN_UtlxN3PuGAxrN2XQnZTVRvDyVWnYq4I6dws";
   private static final String REFRESH_TOKEN = "1/Tl6awhpFjkMkSJoj1xsli0H2eL5YsMgU_NKPY2TyGWY";
@@ -80,7 +75,7 @@ public class GoogleCredentialsTest {
   private static final URI CALL_URI = URI.create("http://googleapis.com/testapi/v1/foo");
 
   private static final Collection<String> SCOPES =
-    Collections.unmodifiableCollection(Arrays.asList("scope1", "scope2"));
+      Collections.unmodifiableCollection(Arrays.asList("scope1", "scope2"));
 
   static class MockHttpTransportFactory implements HttpTransportFactory {
 
@@ -138,8 +133,8 @@ public class GoogleCredentialsTest {
   public void fromStream_serviceAccount_providesToken() throws IOException {
     MockTokenServerTransportFactory transportFactory = new MockTokenServerTransportFactory();
     transportFactory.transport.addServiceAccount(SA_CLIENT_EMAIL, ACCESS_TOKEN);
-    InputStream serviceAccountStream = ServiceAccountCredentialsTest
-        .writeServiceAccountStream(
+    InputStream serviceAccountStream =
+        ServiceAccountCredentialsTest.writeServiceAccountStream(
             SA_CLIENT_ID, SA_CLIENT_EMAIL, SA_PRIVATE_KEY_PKCS8, SA_PRIVATE_KEY_ID);
 
     GoogleCredentials credentials =
@@ -153,32 +148,36 @@ public class GoogleCredentialsTest {
 
   @Test
   public void fromStream_serviceAccountNoClientId_throws() throws IOException {
-    InputStream serviceAccountStream = ServiceAccountCredentialsTest
-        .writeServiceAccountStream(null, SA_CLIENT_EMAIL, SA_PRIVATE_KEY_PKCS8, SA_PRIVATE_KEY_ID);
+    InputStream serviceAccountStream =
+        ServiceAccountCredentialsTest.writeServiceAccountStream(
+            null, SA_CLIENT_EMAIL, SA_PRIVATE_KEY_PKCS8, SA_PRIVATE_KEY_ID);
 
     testFromStreamException(serviceAccountStream, "client_id");
   }
 
   @Test
   public void fromStream_serviceAccountNoClientEmail_throws() throws IOException {
-    InputStream serviceAccountStream = ServiceAccountCredentialsTest
-        .writeServiceAccountStream(SA_CLIENT_ID, null, SA_PRIVATE_KEY_PKCS8, SA_PRIVATE_KEY_ID);
+    InputStream serviceAccountStream =
+        ServiceAccountCredentialsTest.writeServiceAccountStream(
+            SA_CLIENT_ID, null, SA_PRIVATE_KEY_PKCS8, SA_PRIVATE_KEY_ID);
 
     testFromStreamException(serviceAccountStream, "client_email");
   }
 
   @Test
   public void fromStream_serviceAccountNoPrivateKey_throws() throws IOException {
-    InputStream serviceAccountStream = ServiceAccountCredentialsTest
-        .writeServiceAccountStream(SA_CLIENT_ID, SA_CLIENT_EMAIL, null, SA_PRIVATE_KEY_ID);
+    InputStream serviceAccountStream =
+        ServiceAccountCredentialsTest.writeServiceAccountStream(
+            SA_CLIENT_ID, SA_CLIENT_EMAIL, null, SA_PRIVATE_KEY_ID);
 
     testFromStreamException(serviceAccountStream, "private_key");
   }
 
   @Test
   public void fromStream_serviceAccountNoPrivateKeyId_throws() throws IOException {
-    InputStream serviceAccountStream = ServiceAccountCredentialsTest
-        .writeServiceAccountStream(SA_CLIENT_ID, SA_CLIENT_EMAIL, SA_PRIVATE_KEY_PKCS8, null);
+    InputStream serviceAccountStream =
+        ServiceAccountCredentialsTest.writeServiceAccountStream(
+            SA_CLIENT_ID, SA_CLIENT_EMAIL, SA_PRIVATE_KEY_PKCS8, null);
 
     testFromStreamException(serviceAccountStream, "private_key_id");
   }
@@ -227,13 +226,14 @@ public class GoogleCredentialsTest {
     final AtomicReference<Collection<String>> called = new AtomicReference<>();
     final GoogleCredentials expectedScopedCredentials = new GoogleCredentials();
 
-    GoogleCredentials credentials = new GoogleCredentials() {
-      @Override
-      public GoogleCredentials createScoped(Collection<String> scopes) {
-        called.set(scopes);
-        return expectedScopedCredentials;
-      }
-    };
+    GoogleCredentials credentials =
+        new GoogleCredentials() {
+          @Override
+          public GoogleCredentials createScoped(Collection<String> scopes) {
+            called.set(scopes);
+            return expectedScopedCredentials;
+          }
+        };
 
     GoogleCredentials scopedCredentials = credentials.createScoped("foo", "bar");
 
@@ -244,8 +244,9 @@ public class GoogleCredentialsTest {
   private static void testFromStreamException(InputStream stream, String expectedMessageContent) {
     try {
       GoogleCredentials.fromStream(stream, DUMMY_TRANSPORT_FACTORY);
-      fail(String.format("Should throw exception with message containing '%s'",
-          expectedMessageContent));
+      fail(
+          String.format(
+              "Should throw exception with message containing '%s'", expectedMessageContent));
     } catch (IOException expected) {
       assertTrue(expected.getMessage().contains(expectedMessageContent));
     }
