@@ -46,19 +46,15 @@ import com.google.auth.http.AuthHttpConstants;
 import com.google.auth.oauth2.GoogleCredentialsTest.MockTokenServerTransportFactory;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
-
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
-
 import java.io.IOException;
 import java.net.URI;
 import java.util.List;
 import java.util.Map;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
-/**
- * Test case for {@link OAuth2Credentials}.
- */
+/** Test case for {@link OAuth2Credentials}. */
 @RunWith(JUnit4.class)
 public class OAuth2CredentialsTest extends BaseSerializationTest {
 
@@ -70,39 +66,41 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
 
   @Test
   public void constructor_storesAccessToken() {
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(ACCESS_TOKEN, null))
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(ACCESS_TOKEN, null)).build();
     assertEquals(credentials.getAccessToken().getTokenValue(), ACCESS_TOKEN);
   }
 
   @Test
   public void getAuthenticationType_returnsOAuth2() {
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .build();
     assertEquals(credentials.getAuthenticationType(), "OAuth2");
   }
 
   @Test
   public void hasRequestMetadata_returnsTrue() {
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .build();
     assertTrue(credentials.hasRequestMetadata());
   }
 
   @Test
   public void hasRequestMetadataOnly_returnsTrue() {
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .build();
     assertTrue(credentials.hasRequestMetadata());
   }
 
@@ -113,12 +111,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     MockTokenServerTransportFactory transportFactory = new MockTokenServerTransportFactory();
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
-    OAuth2Credentials userCredentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials userCredentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     // Use a fixed clock so tokens don't expire
     userCredentials.clock = new TestClock();
     TestChangeListener listener = new TestChangeListener();
@@ -150,12 +149,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     MockTokenServerTransportFactory transportFactory = new MockTokenServerTransportFactory();
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
-    OAuth2Credentials userCredentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials userCredentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     // Use a fixed clock so tokens don't expire
     userCredentials.clock = new TestClock();
     TestChangeListener listener = new TestChangeListener();
@@ -187,12 +187,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
     TestClock clock = new TestClock();
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     credentials.clock = clock;
 
     // Verify getting the first token
@@ -240,12 +241,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
     TestClock clock = new TestClock();
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     credentials.clock = clock;
 
     MockExecutor executor = new MockExecutor();
@@ -308,12 +310,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
     TestClock clock = new TestClock();
-    OAuth2Credentials credentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials credentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     credentials.clock = clock;
 
     MockExecutor executor = new MockExecutor();
@@ -337,9 +340,8 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
 
   @Test
   public void getRequestMetadata_temporaryToken_hasToken() throws IOException {
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(ACCESS_TOKEN, null))
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(ACCESS_TOKEN, null)).build();
 
     // Verify getting the first token
     Map<String, List<String>> metadata = credentials.getRequestMetadata(CALL_URI);
@@ -353,12 +355,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     MockTokenServerTransportFactory transportFactory = new MockTokenServerTransportFactory();
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
-    OAuth2Credentials userCredentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials userCredentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     // Use a fixed clock so tokens don't expire
     userCredentials.clock = new TestClock();
 
@@ -388,12 +391,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
     MockTokenServerTransportFactory transportFactory = new MockTokenServerTransportFactory();
     transportFactory.transport.addClient(CLIENT_ID, CLIENT_SECRET);
     transportFactory.transport.addRefreshToken(REFRESH_TOKEN, accessToken1);
-    OAuth2Credentials userCredentials = UserCredentials.newBuilder()
-        .setClientId(CLIENT_ID)
-        .setClientSecret(CLIENT_SECRET)
-        .setRefreshToken(REFRESH_TOKEN)
-        .setHttpTransportFactory(transportFactory)
-        .build();
+    OAuth2Credentials userCredentials =
+        UserCredentials.newBuilder()
+            .setClientId(CLIENT_ID)
+            .setClientSecret(CLIENT_SECRET)
+            .setRefreshToken(REFRESH_TOKEN)
+            .setHttpTransportFactory(transportFactory)
+            .build();
     // Use a fixed clock so tokens don't expire
     TestClock mockClock = new TestClock();
     userCredentials.clock = mockClock;
@@ -426,21 +430,18 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
 
   @Test(expected = IllegalStateException.class)
   public void refresh_temporaryToken_throws() throws IOException {
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(ACCESS_TOKEN, null))
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(ACCESS_TOKEN, null)).build();
     credentials.refresh();
   }
 
   @Test
   public void equals_true() throws IOException {
     final String accessToken1 = "1/MkSJoj1xsli0AccessToken_NKPY2";
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken1, null))
-        .build();
-    OAuth2Credentials otherCredentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken1, null))
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken1, null)).build();
+    OAuth2Credentials otherCredentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken1, null)).build();
     assertTrue(credentials.equals(otherCredentials));
     assertTrue(otherCredentials.equals(credentials));
   }
@@ -449,12 +450,10 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
   public void equals_false_accessToken() throws IOException {
     final String accessToken1 = "1/MkSJoj1xsli0AccessToken_NKPY2";
     final String accessToken2 = "2/MkSJoj1xsli0AccessToken_NKPY2";
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken1, null))
-        .build();
-    OAuth2Credentials otherCredentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken2, null))
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken1, null)).build();
+    OAuth2Credentials otherCredentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken2, null)).build();
     assertFalse(credentials.equals(otherCredentials));
     assertFalse(otherCredentials.equals(credentials));
   }
@@ -462,12 +461,13 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
   @Test
   public void toString_containsFields() throws IOException {
     AccessToken accessToken = new AccessToken("1/MkSJoj1xsli0AccessToken_NKPY2", null);
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(accessToken)
-        .build();
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(accessToken).build();
     String expectedToString =
-        String.format("OAuth2Credentials{requestMetadata=%s, temporaryAccess=%s}",
-            ImmutableMap.of(AuthHttpConstants.AUTHORIZATION,
+        String.format(
+            "OAuth2Credentials{requestMetadata=%s, temporaryAccess=%s}",
+            ImmutableMap.of(
+                AuthHttpConstants.AUTHORIZATION,
                 ImmutableList.of(OAuth2Utils.BEARER_PREFIX + accessToken.getTokenValue())),
             accessToken.toString());
     assertEquals(expectedToString, credentials.toString());
@@ -476,19 +476,19 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
   @Test
   public void hashCode_equals() throws IOException {
     final String accessToken = "1/MkSJoj1xsli0AccessToken_NKPY2";
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken, null))
-        .build();
-    OAuth2Credentials otherCredentials = OAuth2Credentials.create(new AccessToken(accessToken, null));
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken, null)).build();
+    OAuth2Credentials otherCredentials =
+        OAuth2Credentials.create(new AccessToken(accessToken, null));
     assertEquals(credentials.hashCode(), otherCredentials.hashCode());
   }
 
   @Test
   public void serialize() throws IOException, ClassNotFoundException {
     final String accessToken = "1/MkSJoj1xsli0AccessToken_NKPY2";
-    OAuth2Credentials credentials = OAuth2Credentials.newBuilder()
-        .setAccessToken(new AccessToken(accessToken, null))
-        .build();    OAuth2Credentials deserializedCredentials = serializeAndDeserialize(credentials);
+    OAuth2Credentials credentials =
+        OAuth2Credentials.newBuilder().setAccessToken(new AccessToken(accessToken, null)).build();
+    OAuth2Credentials deserializedCredentials = serializeAndDeserialize(credentials);
     assertEquals(credentials, deserializedCredentials);
     assertEquals(credentials.hashCode(), deserializedCredentials.hashCode());
     assertEquals(credentials.toString(), deserializedCredentials.toString());
@@ -499,6 +499,7 @@ public class OAuth2CredentialsTest extends BaseSerializationTest {
 
     public AccessToken accessToken = null;
     public int callCount = 0;
+
     @Override
     public void onChanged(OAuth2Credentials credentials) throws IOException {
       accessToken = credentials.getAccessToken();
